from .axes.config import AxConfig as AxConfig
from .axes.config import LegendLoc as LegendLoc
from .axes.config import Scale as Scale
from .axes.config import SpineConfig as SpineConfig
from .axes.resolver import apply_ax_config as apply_ax_config
from .axes.resolver import apply_x_config as apply_x_config
from .axes.resolver import apply_y_config as apply_y_config
from .graph import make_graph as make_graph
